import java.text.DecimalFormat;
import java.util.Date;


/**
 * This class implements a representation of a student.
 * @author hornick
 *
 */
public class Student extends Person {
	
	private Date enrollmentDate;
	private double gpa;		// student's current grade point average
	
/**
 * The one and only constructor for this class
 * @param name - the name to be assigned to the created Student object
 */
	public Student(String name) {
		super(name);
		enrollmentDate = new Date(); // creates the current date, at time of creation
		this.gpa = 0.0; // gets better with time...
	}

	/**
	 * A class implements the Cloneable interface to indicate to the Object.clone() method 
	 * that it is legal for that method to make a field-for-field copy of instances of that class.
	 * Invoking Object's clone method on an instance that does not implement the Cloneable interface 
	 * results in the exception CloneNotSupportedException being thrown.
	 * By convention, classes that implement this interface should override Object.clone 
	 * (which is protected) with a public method. See Object.clone() for details on overriding this method.
	 * 
	 * @return reference to a new Student object which is an identical copy of this object,
	 * or null if CloneNotSupportedException was detected (which should never happen, unless 
	 * the Cloneable interface is not declared on this class).
	 */
/*
	@Override
	public Object clone() throws CloneNotSupportedException {
		Object copy;
		copy = super.clone(); // call Object's clone() method, which makes an identical copy
		return copy;
	}
*/
	public Date getEnrollmentDate() {
		return enrollmentDate;
	}
	
	/**
	 * Accessor
	 * @return the gpa
	 */
	public double getGpa() {
		return gpa;
	}
	
	/**
	 * Mutator
	 * @param gpa - updated gpa
	 */
	public void setGpa( double gpa ) {
		this.gpa = gpa;
	}
	
	/**
	 * override of Object.toString()
	 * @return the String representation for a Student object
	 */
	@Override
	public String toString() {
		DecimalFormat df = new DecimalFormat("0.00");
		String studentString = "Name: " + getName() + ", ID:" + getId() + ", GPA:" + df.format(gpa);
		return studentString;
	}
}
